@@ -176,9 +176,6 @@ ompl::base::PlannerStatus ompl::geometric::LightningRetrieveRepair::solve(const
     if (!perfect_match)
         primaryPath->append(goalState);
 
-    // All save trajectories should be at least 2 states long, and then we append the start and goal states
-    assert(primaryPath->getStateCount() >= 4);
-
     // Repair chosen path
     if (!repairPath(ptc, *primaryPath))
     {
@@ -187,14 +184,15 @@ ompl::base::PlannerStatus ompl::geometric::LightningRetrieveRepair::solve(const
     }
 
     // Smooth the result
-    if(smoothingEnabled_){
-      OMPL_INFORM("LightningRetrieveRepair solve: Simplifying solution (smoothing)...");
-      time::point simplifyStart = time::now();
-      std::size_t numStates = primaryPath->getStateCount();
-      psk_->simplify(*primaryPath, ptc);
-      double simplifyTime = time::seconds(time::now() - simplifyStart);
-      OMPL_INFORM("LightningRetrieveRepair: Path simplification took %f seconds and removed %d states", simplifyTime,
-                  numStates - primaryPath->getStateCount());
+    if (smoothingEnabled_)
+    {
+        OMPL_INFORM("LightningRetrieveRepair solve: Simplifying solution (smoothing)...");
+        time::point simplifyStart = time::now();
+        std::size_t numStates = primaryPath->getStateCount();
+        psk_->simplify(*primaryPath, ptc);
+        double simplifyTime = time::seconds(time::now() - simplifyStart);
+        OMPL_INFORM("LightningRetrieveRepair: Path simplification took %f seconds and removed %d states", simplifyTime,
+                    numStates - primaryPath->getStateCount());
     }
 
     // Finished
@@ -531,13 +529,16 @@ bool ompl::geometric::LightningRetrieveRepair::replan(const ompl::base::State *s
     newPathSegment = static_cast<ompl::geometric::PathGeometric &>(*p);
 
     // Smooth the result
-    OMPL_INFORM("LightningRetrieveRepair: Simplifying solution (smoothing)...");
-    time::point simplifyStart = time::now();
-    std::size_t numStates = newPathSegment.getStateCount();
-    psk_->simplify(newPathSegment, ptc);
-    double simplifyTime = time::seconds(time::now() - simplifyStart);
-    OMPL_INFORM("LightningRetrieveRepair: Path simplification took %f seconds and removed %d states", simplifyTime,
-                numStates - newPathSegment.getStateCount());
+    if (smoothingEnabled_)
+    {
+        OMPL_INFORM("LightningRetrieveRepair: Simplifying solution (smoothing)...");
+        time::point simplifyStart = time::now();
+        std::size_t numStates = newPathSegment.getStateCount();
+        psk_->simplify(newPathSegment, ptc);
+        double simplifyTime = time::seconds(time::now() - simplifyStart);
+        OMPL_INFORM("LightningRetrieveRepair: Path simplification took %f seconds and removed %d states", simplifyTime,
+                    numStates - newPathSegment.getStateCount());
+    }
 
     // Save the planner data for debugging purposes
     repairPlannerDatas_.push_back(std::make_shared<ompl::base::PlannerData>(si_));
